==> haskell-contravariant-extras-0.3.4-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui
key: contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: 58b93e15034d8eff836872339341af39
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui
depends:
    base-4.11.1.0 tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA
    template-haskell-2.13.0.0
    contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA=61e77e3aac5fd226d5ea0f5b7e73ae9c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=c99faff75f3a482d24cfc7bf782693a7
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-G0FtwWS1Rt48QPt2Rs62my
key: contravariant-extras-0.3.4-G0FtwWS1Rt48QPt2Rs62my
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: 26f92f5a16f6701659c713c1cffd1422
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-G0FtwWS1Rt48QPt2Rs62my
depends:
    base-4.11.1.0 tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA
    template-haskell-2.13.0.0 contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA=61e77e3aac5fd226d5ea0f5b7e73ae9c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=d2f13618f92bbccf0540968a185d3c43
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
